@@ -1,13 +1,14 @@
 package Form::Tiny::Filter;
 
-use v5.10; use warnings;
+use v5.10;
+use warnings;
 use Moo;
 use Types::Standard qw(HasMethods CodeRef);
 use Carp qw(croak);
 
 use namespace::clean;
 
-our $VERSION = '1.01';
+our $VERSION = '1.10';
 
 has "type" => (
 	is => "ro",
