@@ -1,9 +1,10 @@
 package Form::Tiny::Form;
 
-use v5.10; use warnings;
+use v5.10;
+use warnings;
 use Moo::Role;
 
-our $VERSION = '1.01';
+our $VERSION = '1.10';
 
 requires qw(validate check);
 
